atari

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2026 License: BSD-1-Clause Imports: 3 Imported by: 0

Documentation

Overview

Package atari provides the Atari ST text encoding.

This package implements the golang.org/x/text/encoding interface for the Atari ST/TT (TOS) character encoding, which was used on Atari ST, STe, TT, and Falcon computers.

Supported Encodings

  • ST - Atari ST encoding

Usage

The encoding provides NewDecoder() and NewEncoder() methods:

import "github.com/go-sw/text-codec/atari"

// Decode Atari ST to UTF-8
decoder := atari.ST.NewDecoder()
utf8Bytes, err := decoder.Bytes(atariBytes)

// Encode UTF-8 to Atari ST
encoder := atari.ST.NewEncoder()
atariBytes, err := encoder.Bytes(utf8Bytes)

For streaming, use with golang.org/x/text/transform:

import "golang.org/x/text/transform"

reader := transform.NewReader(file, atari.ST.NewDecoder())
writer := transform.NewWriter(file, atari.ST.NewEncoder())

Data Source

The encoding table is derived from Unicode Consortium mapping files available at https://www.unicode.org/Public/MAPPINGS/VENDORS/MISC/. See the NOTICE file for licensing information.

Index

Constants

This section is empty.

Variables

var ST encoding.Encoding = &sTEncoding{}

ST is the Atari ST encoding.

Functions

This section is empty.

Types

type UnencodableRuneError

type UnencodableRuneError struct {
	Rune     rune
	Encoding string
}

UnencodableRuneError is returned when a Unicode rune cannot be encoded in the target encoding.

func (*UnencodableRuneError) Error

func (e *UnencodableRuneError) Error() string

Jump to